@@ -4,11 +4,7 @@ from pyroute2.ipdb import IPDB
 from pyroute2.netlink.rtnl import IPRSocket
 from pyroute2.netlink.taskstats import TaskStats
 from pyroute2.netlink.ipq import IPQSocket
-from pyroute2.netlink.ipq import IPQ
 from pyroute2.netlink.generic import GenericNetlinkSocket
-from pyroute2.netlink.generic import GenericNetlink
-from pyroute2.iocore.iocore import IOCore
-from pyroute2.iocore import TimeoutError
 from pyroute2.netlink import NetlinkError
 
 modules = [IPRSocket,
@@ -16,11 +12,7 @@ modules = [IPRSocket,
            IPDB,
            TaskStats,
            IPQSocket,
-           IPQ,
            GenericNetlinkSocket,
-           GenericNetlink,
-           IOCore,
-           TimeoutError,
            NetlinkError]
 
 __all__ = [getattr(module, '__name__') for module in modules]
