@@ -128,7 +128,10 @@ class ifinfmsg(nlmsg):
                ('IFLA_EXT_MASK', 'hex'),
                ('IFLA_PROMISCUITY', 'uint32'),
                ('IFLA_NUM_TX_QUEUES', 'uint32'),
-               ('IFLA_NUM_RX_QUEUES', 'uint32'))
+               ('IFLA_NUM_RX_QUEUES', 'uint32'),
+               ('IFLA_CARRIER', 'uint8'),
+               ('IFLA_PHYS_PORT_ID', 'hex'),
+               ('IFLA_CARRIER_CHANGES', 'uint32'))
 
     @staticmethod
     def flags2names(flags, mask=0xffffffff):
@@ -188,7 +191,9 @@ class ifinfmsg(nlmsg):
         nla_map = (('IFLA_INFO_UNSPEC', 'none'),
                    ('IFLA_INFO_KIND', 'asciiz'),
                    ('IFLA_INFO_DATA', 'info_data'),
-                   ('IFLA_INFO_XSTATS', 'hex'))
+                   ('IFLA_INFO_XSTATS', 'hex'),
+                   ('IFLA_INFO_SLAVE_KIND', 'asciiz'),
+                   ('IFLA_INFO_SLAVE_DATA', 'info_data'))
 
         def info_data(self, *argv, **kwarg):
             '''
@@ -218,7 +223,39 @@ class ifinfmsg(nlmsg):
         class bond_data(nla):
             nla_map = (('IFLA_BOND_UNSPEC', 'none'),
                        ('IFLA_BOND_MODE', 'uint8'),
-                       ('IFLA_BOND_ACTIVE_SLAVE', 'uint32'))
+                       ('IFLA_BOND_ACTIVE_SLAVE', 'uint32'),
+                       ('IFLA_BOND_MIIMON', 'uint32'),
+                       ('IFLA_BOND_UPDELAY', 'uint32'),
+                       ('IFLA_BOND_DOWNDELAY', 'uint32'),
+                       ('IFLA_BOND_USE_CARRIER', 'uint8'),
+                       ('IFLA_BOND_ARP_INTERVAL', 'uint32'),
+                       ('IFLA_BOND_ARP_IP_TARGET', 'arp_ip_target'),
+                       ('IFLA_BOND_ARP_VALIDATE', 'uint32'),
+                       ('IFLA_BOND_ARP_ALL_TARGETS', 'uint32'),
+                       ('IFLA_BOND_PRIMARY', 'uint32'),
+                       ('IFLA_BOND_PRIMARY_RESELECT', 'uint8'),
+                       ('IFLA_BOND_FAIL_OVER_MAC', 'uint8'),
+                       ('IFLA_BOND_XMIT_HASH_POLICY', 'uint8'),
+                       ('IFLA_BOND_RESEND_IGMP', 'uint32'),
+                       ('IFLA_BOND_NUM_PEER_NOTIF', 'uint8'),
+                       ('IFLA_BOND_ALL_SLAVES_ACTIVE', 'uint8'),
+                       ('IFLA_BOND_MIN_LINKS', 'uint32'),
+                       ('IFLA_BOND_LP_INTERVAL', 'uint32'),
+                       ('IFLA_BOND_PACKETS_PER_SLAVE', 'uint32'),
+                       ('IFLA_BOND_AD_LACP_RATE', 'uint8'),
+                       ('IFLA_BOND_AD_SELECT', 'uint8'),
+                       ('IFLA_BOND_AD_INFO', 'ad_info'))
+
+            class ad_info(nla):
+                nla_map = (('IFLA_BOND_AD_INFO_UNSPEC', 'none'),
+                           ('IFLA_BOND_AD_INFO_AGGREGATOR', 'uint16'),
+                           ('IFLA_BOND_AD_INFO_NUM_PORTS', 'uint16'),
+                           ('IFLA_BOND_AD_INFO_ACTOR_KEY', 'uint16'),
+                           ('IFLA_BOND_AD_INFO_PARTNER_KEY', 'uint16'),
+                           ('IFLA_BOND_AD_INFO_PARTNER_MAC', 'l2addr'))
+
+            class arp_ip_target(nla):
+                fields = (('targets', '16I'), )
 
     class af_spec(nla):
         nla_map = (('AF_UNSPEC', 'none'),
@@ -271,7 +308,8 @@ class ifinfmsg(nlmsg):
                        ('IFLA_INET6_STATS', 'ipv6_stats'),
                        ('IFLA_INET6_MCAST', 'hex'),
                        ('IFLA_INET6_CACHEINFO', 'ipv6_cache_info'),
-                       ('IFLA_INET6_ICMP6STATS', 'icmp6_stats'))
+                       ('IFLA_INET6_ICMP6STATS', 'icmp6_stats'),
+                       ('IFLA_INET6_TOKEN', 'ip6addr'))
 
             class ipv6_devconf(nla):
                 # ./include/uapi/linux/ipv6.h
